----------------------------------------------------------------------
-- FILE: REDACT_SPEC.SQL
-- AUTHOR: Huy Nguyen, Sharon Newman, Yang-Jia Deng
-- DATE: October 18th, 2004
-- PURPOSE: The main redaction package that performs the counts and deletes
-- CALLS: See package specs 
-- CALLED BY: Manually run by 'exec redaction_pkg.main'
-- PARAMETERS:  None
-- ORACLE VERSION: 8.1.7
--
-- CHANGE HISTORY:
-- RequestID    Date       Author        Description                   
-----------------------------------------------------------------------
-- <request#>   <date>     <developer>   <description and reason>
----------------------------------------------------------------------------------------------------------

create or replace package redaction_pkg as

  -- global variables required for error message handling
  -- made public so separate write procedures can access
  v_process_name    varchar2 ( 20 );
  v_process_step    varchar2 ( 20 );
  v_table_name      varchar2 ( 30 );
  v_error_nbr       varchar2 ( 10 );
  v_error_msg       varchar2 ( 256 );
  v_district        varchar2 ( 10 );
  v_caseid          varchar2 ( 10 );
  v_partid          number ( 10 );
  v_count           number;

  -- variables to write records and redact records to file
  v_file_header     utl_file.file_type;
  v_write_location  varchar2 ( 256 ) := 'REDACT_DIR';
  c_linesize        number := 2000;
  c_mask            varchar2 ( 1 ) := '*';

  function error_check return number;

  procedure write_error;

  procedure log_record_count ( p_process_name  IN varchar2,
                               p_table_name  IN varchar2,
                               p_count  IN number );

  procedure reset_tables;

  procedure baseline_count ( p_process_name  IN varchar2 );

  procedure marked_expunged;

  procedure sealed_civil;

  procedure sealed_criminal;

  procedure ongoing_investigations;

  procedure post_disposition;

  procedure expunge_cases ( p_process_name  IN varchar2 );

  -- only public interface to package
  function calculate_prior_previous ( p_date  IN varchar2 ) return date;

  PRAGMA restrict_references ( calculate_prior_previous, WNDS, WNPS );

  procedure main ( p_date  IN varchar2 );

end redaction_pkg;
/
sho err